@@ -1,4 +1,5 @@
 from lzw_c import *
+from lz77c import lz77_decompress
 
 def glue_seq(seq, last_separate = False):
     if last_separate:
@@ -12,7 +13,7 @@ def code_filling(huff_codes):
     codes = {}
     for seq, code in huff_codes.items():
         cd = int("1" + code, 2)
-        sequences[cd] = lzw_compress(seq)
+        sequences[cd] = lzw_compress(str(seq))
         codes[seq] = code
     return sequences, codes
 
@@ -28,4 +29,10 @@ def huffman_decode(sequences, compressed):
 
 def org_shaping(seq, bits):
     org = " ".join(huffman_decode(seq, bits)).split()
-    return [i.replace("__", " ") for i in org]
\ No newline at end of file
+    org = [i.replace("__", " ") for i in org]
+    return [eval(i) for i in org]
+
+def lz77_decode(triplets):
+    triplets = list(zip(triplets[0], triplets[1], triplets[2]))
+    decomp = lz77_decompress(triplets)
+    return decomp
\ No newline at end of file
